@@ -2,13 +2,18 @@ import urllib2
 import json
 import datetime
 import smtplib
+import os.path
+import ConfigParser
 from email.mime.text import MIMEText
 
+config= ConfigParser.ConfigParser()
+config.read(os.path.expanduser('~/.altin.conf'))
+
 SMTP_SERVER = "smtp.gmail.com" #SMTP server for gmail
 SMTP_PORT = 587 #SMTP port for gmail
-SMTP_USERNAME = "*****"
-SMTP_PASSWORD = "****"
-EMAIL_TO = "******"
+SMTP_USERNAME = config.get('UserInfo','SMTP_USERNAME')
+SMTP_PASSWORD = config.get('UserInfo','SMTP_PASSWORD')
+EMAIL_TO = config.get('UserInfo','EMAIL_TO')
 EMAIL_FROM = "bilgi@altinfiyat.com" #You may change this mail address
 EMAIL_SUBJECT = "Gold price notifier" #You may change this subject
 
@@ -39,12 +44,13 @@ def send_email(message_to_be_send):
     mail.login(SMTP_USERNAME, SMTP_PASSWORD)
     mail.sendmail(EMAIL_FROM, EMAIL_TO, msg.as_string())
     mail.quit()
-url_ceyrek = "http://api.piyasa.com/json/?kaynak=metal_arsiv_ay_alti_CYR" #API for ceyrek
-url_gram = "http://api.piyasa.com/json/?kaynak=metal_arsiv_ay_alti_GRM" #API for gram
-message = "---Ceyrek altin fiyatlari--- \n\n %s\n" % get_data(url_ceyrek,
+
+def main():
+    url_ceyrek = "http://api.piyasa.com/json/?kaynak=metal_arsiv_ay_alti_CYR" #API for ceyrek
+    url_gram = "http://api.piyasa.com/json/?kaynak=metal_arsiv_ay_alti_GRM" #API for gram
+    message = "---Ceyrek altin fiyatlari--- \n\n %s\n" % get_data(url_ceyrek,
                                                     "ceyrek altin fiyati")
 
-message += "---Gram altin fiyatlari--- \n\n %s\n" % get_data(url_gram,
+    message += "---Gram altin fiyatlari--- \n\n %s\n" % get_data(url_gram,
                                                     "gram altin fiyati")
-
-send_email(message)
+    send_email(message)
